/*******************
Ad Format: Pushdown
Amazon Template Version: 1.0.1
Last Updated On: 2023-02-20
*******************/

/*******************
VARIABLES
*******************/
var creativeId = "Banner"; //Use anything that uniquely identifies this creative
var creativeVersion = "2.2.0"; //0.0.1 during initial dev, 1.0.0 on release, x.x.x once released and receives updates
var lastModified = "2021-05-17";
var lastUploaded = "2021-05-17";

var templateVersion = "2.0.23";

var adId, rnd, uid;
var bannerDiv;
var expandButton;
var expandType;
var cta_btn;
var user_action_btn;
var panelName;
var bannerWidth;
var bannerHeight;
var panelWidth;
var panelHeight;
var PANEL_WIDTH_DEPENDENCY;
var PANEL_HEIGHT_DEPENDENCY;
var panelAutoBreakPoints;
var panelUserBreakPoints;
var parentViewPort;
var initComplete;
var ccReady;
var sdkData;
var isMRAID;

/*******************
INITIALIZATION
*******************/

function initializeCreative(event) {
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function() {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function() {
		eventManager.apply(this, arguments);
	}, this);

	EB.Comm = EB.Comm || new EBG.Comm();
	EB.Comm.setName("banner");




	initializeGlobalVariables();
	initializeCloseButton();
	addEventListeners();
	setCreativeVersion();

	dispatchCustomScriptEvent("compatibilityMode", {
		mode: false
	}); //do not remove this line - allows for backwards compatibility

	if (isMRAID) {
		document.addEventListener("touchmove", function(event) {
			event.preventDefault();
		});
	}

	initComplete = true;
}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;
	creativeIFrameId = EB.assetId;

	bannerDiv = document.getElementById("banner");
	expandButton = document.getElementById("expand_btn");
	cta_btn= document.getElementById("cta_btn");
	user_action_btn= document.getElementById("user_action_btn");

	document.getElementById("expand_btn").innerHTML = adkit.getSVData("expand_btn_txt");
	document.getElementById("user_action_btn").innerHTML = adkit.getSVData("user_action_txt");
	document.getElementById("cta_btn").innerHTML = adkit.getSVData("cta_txt");
	document.getElementById("logo").src = adkit.getSVData("logo_img");


	if (!isMRAID) {
		sdkData = EB.getSDKData();
		isMRAID = sdkData !== null && sdkData.SDKType === "MRAID";
	}
}

function initializeCloseButton() {
	var useCustomClose = !isMRAID || (isMRAID && !getCustomVar("mdEnableSDKDefaultCloseButton"));
	EB.setExpandProperties({
		useCustomClose: useCustomClose
	});
}

function addEventListeners() {
	expandButton.addEventListener("click", handleExpandButtonClick);
	cta_btn.addEventListener("click", handleClickthroughButtonClick);
	user_action_btn.addEventListener("click", handleUserActionButtonClick);
}

function registerInteraction() {
	//Register your automatic and user interactions here and the platform will parse them on workspace upload. This function will not be called.
	//Example: 'Left_Gutter_Viewed'

	//EB.automaticEventCounter("interactionName1");
	//EB.automaticEventCounter("interactionName2");

	//EB.userActionCounter("userActionName1");
	//EB.userActionCounter("userActionName2");
}

/*******************
EVENT HANDLERS
*******************/
function handleExpandButtonClick() {
	if (EB.API.getStyle(expandButton,"display").toLowerCase() !== "none") {
		openPanel(false);
	}
}

function handleClickthroughButtonClick() {
	EB.clickthrough();
}

function handleUserActionButtonClick() {
	EB.userActionCounter("CustomInteraction");
}

/*******************
UTILITIES
*******************/
function showMessage(msg) {
	// listen to comm module call back 
}

function panelListener(event) {
	if (event.action === "AnimationStart" && !EB.API.Adaptor.getAdData("isSafeFrame")) {
		EB.API.setStyle(expandButton, {
			display: "none"
		});
	}
	if (event.action === "AnimationComplete") {
		EB.API.setStyle(expandButton, {
			display: "block"
		});
	}
}

function getCustomVar(cv) {
	cv = EB.API.getCustomVar(cv);
	if (typeof(cv) != "undefined") {
		return cv;
	}
	else {
		return "noVarFound";
	}
}

function setCreativeVersion() {
	sendMessage("setCreativeVersion", {
		creativeId: creativeId,
		creativeVersion: creativeVersion,
		creativeLastModified: lastModified,
		uid: uid
	});
}

function creativeContainerReady() {
	if (ccReady) {
		return;
	}

	if (!initComplete) {
		setTimeout(creativeContainerReady, 500);
		return;
	}
	else {
		if (getCustomVar("mdIsAutoExpand")) {
			openPanel(true);
		}
		ccReady = true;
	}
}

function openPanel(isAuto) {
	var actionType = isAuto ? EBG.ActionType.AUTO : EBG.ActionType.USER;
	panelName = isAuto ? getCustomVar("mdAutoPanelName") : getCustomVar("mdUserPanelName");
	expandType = isAuto ? getCustomVar("mdAutoPanelType") : getCustomVar("mdUserPanelType");

	if (isMRAID) {
		EB.expand({
			panelName: panelName,
			width: 1,
			height: 1,
			actionType: actionType
		});
	}
	else {
		var push = false;
		var duration = 0;
		var init = {};

		if (expandType.match(/pushdown/i) !== null) {
			push = {
				deltaOffset: 0
			};
			duration = getCustomVar("mdAnimationDuration") * 1000;
		}

		var initPanelHeight = bannerHeight;
		if (expandType.match(/fullscreen/i) !== null) {
			init.top = 0;
			init.left = 0;
			initPanelHeight = 0;
			panelWidth = parentViewPort.width;
			if (!EB.API.os.mobile) {
				panelWidth += 17;
			}
			panelHeight = parentViewPort.height;
		}
		else {
			panelWidth = getPanelWidth(isAuto);
			panelHeight = getPanelHeight(isAuto);
		}

		init.clip = "rect(" + initPanelHeight + "px," + Math.max(EB._adConfig.width, panelWidth) + "px, 0px, 0px)";
		init.width = panelWidth;
		EB.expand({
			animate: {
				init: init,
				clip: "rect(0px," + panelWidth + "px," + panelHeight + "px, 0px)",
				width: panelWidth + "px",
				height: panelHeight + "px",
				duration: duration,
				easing: getCustomVar("mdEasingType"),
				customData: {
					action: expandType
				}
			},
			panelName: panelName,
			pushdown: push,
			actionType: actionType
		});
	}
}

function getPanelFixedSize(isAuto) {
	var sizeSource = isAuto ? getCustomVar("mdAutoPanelFixedSize") : getCustomVar("mdUserPanelFixedSize");
	if (sizeSource !== "undefined" && sizeSource.match(/^\d+x\d+$/i) !== null) {
		return {
			width: sizeSource.split(/[^(\d|\.)]+/)[0] * 1,
			height: sizeSource.split(/[^(\d|\.)]+/)[1] * 1
		};
	}
	else {
		return {
			width: bannerWidth,
			height: bannerHeight
		};
	}
}

function getPanelWidth(isAuto) {
	var panelWidthDependency = getCustomVar("mdPanelWidthDependency");
	if (expandType.match(/pushdown/i) !== null) {
		panelWidthDependency = PANEL_WIDTH_DEPENDENCY.MATCH_BANNER;
	}
	var newPanelWidth = bannerWidth;
	switch (panelWidthDependency.toLowerCase()) {
		case PANEL_WIDTH_DEPENDENCY.FIXED:
			newPanelWidth = getPanelFixedSize(isAuto).width;
			break;
		case PANEL_WIDTH_DEPENDENCY.ADAPTIVE:
			var breakPoints = isAuto ? panelAutoBreakPoints : panelUserBreakPoints;
			if (breakPoints !== undefined) {
				newPanelWidth = breakPoints[0].width;
				for (var i = 0; i < breakPoints.length; i++) {
					if (breakPoints[i].width <= parentViewPort.width) {
						newPanelWidth = breakPoints[i].width;
					}
				}
			}
			break;
		case PANEL_WIDTH_DEPENDENCY.ASPECT_RATIO:
			var panelAspectRatio = getCustomVar("mdPanelAspectRatio");
			if (panelAspectRatio !== undefined && panelAspectRatio.match(/\d+:\d+/) !== null) {
				newPanelWidth = parseInt((panelHeight / panelAspectRatio.split(":")[1]) * panelAspectRatio.split(":")[0]);
			}
			break;
		case PANEL_WIDTH_DEPENDENCY.BROWSER:
			newPanelWidth = parentViewPort.width;
			break;
		default: // PANEL_WIDTH_DEPENDENCY.MATCH_BANNER
			newPanelWidth = bannerWidth;
			break;
	}
	return newPanelWidth;
}

function getPanelHeight(isAuto) {
	var panelHeightDependency = getCustomVar("mdPanelHeightDependency");
	var newPanelHeight = bannerHeight;
	switch (panelHeightDependency.toLowerCase()) {
	case PANEL_HEIGHT_DEPENDENCY.FIXED:
		newPanelHeight = getPanelFixedSize(isAuto).height;
		break;
	case PANEL_HEIGHT_DEPENDENCY.ADAPTIVE:
		var breakPoints = isAuto ? panelAutoBreakPoints : panelUserBreakPoints;
		if (breakPoints !== undefined) {
			newPanelHeight = breakPoints[0].height;
			for (var i = 0; i < breakPoints.length; i++) {
				if (breakPoints[i].width <= parentViewPort.width) {
					newPanelHeight = breakPoints[i].height;
				}
			}
		}
		break;
	case PANEL_HEIGHT_DEPENDENCY.ASPECT_RATIO:
		var panelAspectRatio = getCustomVar("mdPanelAspectRatio");
		if (panelAspectRatio !== undefined && panelAspectRatio.match(/\d+:\d+/) !== null) {
			newPanelHeight = parseInt((panelWidth / panelAspectRatio.split(":")[0]) * panelAspectRatio.split(":")[1]);
		}
		break;
	case PANEL_HEIGHT_DEPENDENCY.BROWSER:
		newPanelHeight = parentViewPort.height;
		break;
	default: //PANEL_HEIGHT_DEPENDENCY.MATCH_BANNER
		newPanelHeight = bannerHeight;
		break;
	}
	return newPanelHeight;
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if (!data.type) {
		data.type = type;
	}
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId]) {
		delete listenerQueue[listenerId];
	}
}

function eventManager(event) {
	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);
	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			isMRAID = msg.data.mraid;
			parentViewPort = msg.data.viewport;
			bannerWidth = msg.data.bannerWidth;
			bannerHeight = msg.data.bannerHeight;
			panelAutoBreakPoints = msg.data.panelAutoBreakPoints;
			panelUserBreakPoints = msg.data.panelUserBreakPoints;
			PANEL_WIDTH_DEPENDENCY = msg.data.panelWidthDependency;
			PANEL_HEIGHT_DEPENDENCY = msg.data.panelHeightDependency;
			addCustomScriptEventListener("panelBehaviour", panelListener, false);
			addCustomScriptEventListener("parentViewPort", function(event) {
				parentViewPort = event.viewport;
			}, false);
			addCustomScriptEventListener("currentExpandData", function(event) {
				bannerWidth = event.bannerWidth;
				bannerHeight = event.bannerHeight;
			}, false);
			if (creativeContainerReady)
				creativeContainerReady();
			break;
		case "animationComplete":
			panelListener({
				action: msg.data.action,
				expanding: msg.data.expanding
			});
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for (var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if (!t) continue;
					t.callback(msg.data);
				}
				catch (e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function() {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

adkit.onReady(initializeCreative);