/*******************
Ad Format: Pushdown
Amazon Template Version: 1.0.1
Last Updated On: 2023-02-20
*******************/

/*******************
VARIABLES
*******************/
var lastModified = "2021-05-17";
var lastUploaded = "2021-05-17";

var templateVersion = "2.0.23";

var adId, rnd, uid;
var expansionDiv;
var closeButton;
var userActionButton;
var clickthroughButton;
var videoTrackingModule;
var video;
var expandType;
var duration;
var easing;
var panelName;
var bannerWidth;
var bannerHeight;
var sdkData;
var isMRAID;
var useCustomClose;
var playContentDelayTimer;

/*******************
INITIALIZATION
*******************/

function initializeCreative(event) {
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function() {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function() {
		eventManager.apply(this, arguments);
	}, this);

	EB.Comm = EB.Comm || new EBG.Comm();
	EB.Comm.setName("expandUser");




	initializeGlobalVariables();
	initializeCloseButton();
	addEventListeners();

	easing = getCustomVar("mdEasingType");
	panelName = getCustomVar("mdUserPanelName");
	expandType = getCustomVar("mdUserPanelType");
	duration = expandType.match(/pushdown/i) !== null ? getCustomVar("mdAnimationDuration") * 1000 : 0;

	if (!EB.API.os.ios && !isNativeAndroidBrowser()) {
		playContentDelayTimer = setTimeout(function() {
			video.muted = true;
		}, duration);
	}

	if (isMRAID || (getCustomVar("mdUserPanelType").match(/fullscreen/i) !== null && getCustomVar("mdLockScrollingWhenExpanded"))) {
		preventPageScrolling();
	}
}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	expansionDiv = document.getElementById("expansion");
	closeButton = document.getElementById("user_expand_close_btn");
	userActionButton = document.getElementById("user_expand_user_action_btn");
	clickthroughButton = document.getElementById("user_expand_clickthrough_btn");
	video = document.getElementById("video");

	document.getElementById("logo").src = adkit.getSVData("logo_img");
	document.getElementById("user_expand_close_btn").innerHTML = adkit.getSVData("close_btn_txt");
	document.getElementById("user_expand_user_action_btn").innerHTML = adkit.getSVData("user_action_txt");
	document.getElementById("user_expand_clickthrough_btn").innerHTML = adkit.getSVData("cta_txt");
	video.src =  adkit.getSVData("video");

	if (!isMRAID) {
		sdkData = EB.getSDKData();
		isMRAID = sdkData !== null && sdkData.SDKType === "MRAID";
	}
}

function initializeCloseButton() {
	useCustomClose = !isMRAID || (isMRAID && !getCustomVar("mdEnableSDKDefaultCloseButton"));
	if (useCustomClose) {
		EB.API.setStyle(closeButton, {
			display: "block"
		});
	}
}

function initializeVideoTracking() {
	videoTrackingModule = new EBG.VideoModule(video);
}

function addEventListeners() {
	closeButton.addEventListener("click", handleCloseButtonClick);
	userActionButton.addEventListener("click", handleUserActionButtonClick);
	clickthroughButton.addEventListener("click", handleClickthroughButtonClick);

	if (isMRAID) {
		sendMessage("checkMRAIDState", {
			panelName: panelName
		});
	}

	if (video && (isMRAID || (getCustomVar("mdUserPanelType").match(/fullscreen/i) !== null && getCustomVar("mdLockScrollingWhenExpanded")))) {
		video.addEventListener("touchstart", allowPageScrolling);
		video.addEventListener("touchend", preventPageScrolling);
	}
}

/*******************
EVENT HANDLERS
*******************/
function handleCloseButtonClick() {
	pauseVideo();
	clearTimeout(playContentDelayTimer);

	if (EB.Comm.isConnected("banner")) {
		EB.Comm.banner.showMessage("expand panel collapsed");
	}

	if (isMRAID) {
		EB.collapse({
			panelName: panelName
		});
		return;
	}

	if (EB.API.os.android || expandType.match(/fullscreen/i) !== null) {
		bannerHeight = 0;
	}

	EB.collapse({
		animate: {
			clip: "rect(" + bannerHeight + "px," + EB.API.Adaptor.getViewPortMetrics().width + "px, 0px, 0px)",
			duration: duration,
			easing: easing,
			alignToElement: false,
			customData: {
				action: "collapse_" + expandType
			}
		},
		panelName: panelName,
	});
}

function handleUserActionButtonClick() {
	EB.userActionCounter("CustomInteraction");
}

function handleClickthroughButtonClick() {
	pauseVideo();
	clearTimeout(playContentDelayTimer);
	EB.clickthrough();
	handleCloseButtonClick();
}

/*******************
UTILITIES
*******************/
function showMessage(msg) {
	// listen to comm module call back 
}

function panelListener(event) {
	if (event.action === "AnimationStart" && !EB.API.Adaptor.getAdData("isSafeFrame")) {
		EB.API.setStyle(closeButton, {
			display: "none"
		});
	}
	if (useCustomClose && event.action === "AnimationComplete") {
		EB.API.setStyle(closeButton, {
			display: "block"
		});
	}
}

function isNativeAndroidBrowser() {
	var ua = navigator.userAgent;
	var androidOS = ua.match(/android/i) !== null;
	var applewebkitString = ua.match(/AppleWebKit\/([\d.]+)/i);
	var appleWebKitVersion = applewebkitString !== null ? parseFloat(applewebkitString[1]) : 536;
	var chromeString = ua.match(/Chrome\/([\d.]+)/i);
	var chromeVersion = chromeString !== null ? parseFloat(chromeString[1]) : 30;
	var samsungBrowser = ua.match(/samsung/i) !== null;
	return (androidOS && appleWebKitVersion >= 537 && chromeVersion <= 49) || samsungBrowser;
}

function preventPageScrolling() {
	document.addEventListener("touchmove", stopScrolling);
}

function allowPageScrolling() {
	document.removeEventListener("touchmove", stopScrolling);
}

function stopScrolling(event) {
	if (!video.contains(event.target)) {
		event.preventDefault();
	}
}

// EBCMD function
function collapse() {
	handleCloseButtonClick();
}

function getCustomVar(cv) {
	cv = EB.API.getCustomVar(cv);
	if (typeof(cv) != "undefined") {
		return cv;
	}
	else {
		return "noVarFound";
	}
}

function pauseVideo() {
	var videos = document.getElementsByTagName("video");
	for (var i = 0; i < videos.length; i++) {
		if (!videos[i].paused) {
			videos[i].pause();
		}
	}
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if (!data.type) {
		data.type = type;
	}
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId]) {
		delete listenerQueue[listenerId];
	}
}

function eventManager(event) {
	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);
	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}

	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			isMRAID = msg.data.mraid;
			bannerWidth = msg.data.bannerWidth;
			bannerHeight = msg.data.bannerHeight;
			addCustomScriptEventListener("currentExpandData", function(event) {
				bannerWidth = event.bannerWidth;
				bannerHeight = event.bannerHeight;
			}, false);
			addCustomScriptEventListener("panelBehaviour", panelListener, false);
			break;
		case "animationComplete":
			panelListener({
				action: msg.data.action,
				expanding: msg.data.expanding
			});
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for (var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if (!t) continue;
					t.callback(msg.data);
				}
				catch (e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function() {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

adkit.onReady(initializeCreative);